Crate another_steam_totp

Provides functionality relating to Steam TOTP. Based on https://github.com/DoctorMcKay/node-steam-totp. Designed to be easy-to-use while providing all necessary features.

Usage

use another_steam_totp::generate_auth_code;
 
let shared_secret = "000000000000000000000000000=";
let time_offset = None;
// Generates the 5-character time-based one-time password using
// your shared_secret.
let code = generate_auth_code(shared_secret, time_offset).unwrap();
 
assert_eq!(code.len(), 5);

Enums

Error
Any number of errors that can occur during code generations.
Tag
The tag used in generate_confirmation_key.

Functions

generate_auth_code
Generates the 5-character authentication code to login to Steam using your base64-encoded or hex-encoded shared_secret.
generate_confirmation_key
Generates a confirmation key for responding to mobile confirmations using your base64-encoded or hex-encoded identity_secret.
get_device_id
Gets the device ID for a given 64-bit steamid.
get_device_id_with_salt
Gets the device ID for a given 64-bit steamid with a salt.
get_steam_server_time_offset
Gets how many seconds we are behind Steam’s servers.
get_steam_server_time_offset_sync
Gets how many seconds we are behind Steam’s servers.